Macros
- html
- This macro implements a syntax for creating HTML Nodes.
Structs
- Descendants
- Node
- A handle to a node in a DOM-like tree.
- Parser
Error - An error that occurs while constructing an HTML tree.
- Selection
- An iterator of nodes matching a particular css selector.
Enums
Functions
- comment
- Returns a new comment node with the given contents.
- deep_
copy - Creates a deep-copy of
nodeby recursively building a tree out of deep copies of its children. - doctype
- Returns a new doctype “html” node.
- fragment
- Returns a new fragment with the given nodes.
- mark_
foreign_ subtree - Marks
rootand all descendant element nodes as belonging to a foreign namespace. - parse
- Parses the given HTML fragment.
- raw_
text - Returns a new text node with the given contents.
- select
- Returns a new iterator that only yields elements from
itermatching the given CSS selector. - tag
- Returns a new element node with the given name and attributes.
- text
- Returns a new text node with the given contents.